@@ -219,7 +219,7 @@ class ModelAccess(object):
             self._models = rpc.execute('model', 'ir.model', 'list_models',
                 rpc.CONTEXT)
         except TrytonServerError:
-            pass
+            logger.error("Unable to get model list.")
 
     def __getitem__(self, model):
         if model in self._access:
@@ -233,7 +233,14 @@ class ModelAccess(object):
             access = rpc.execute('model', 'ir.model.access', 'get_access',
                 self._models[to_load], rpc.CONTEXT)
         except TrytonServerError:
-            access = {}
+            logger.error("Unable to get access for %s.", model)
+            access = {
+                model: {
+                    'read': True,
+                    'write': False,
+                    'create': False,
+                    'delete': False},
+                }
         self._access.update(access)
         return self._access[model]
 
@@ -1135,7 +1142,7 @@ class RPCProgress(object):
 
         def return_():
             if self.exception:
-                raise self.exception
+                raise RPCException(self.exception)
             else:
                 return self.res
 
