@@ -113,11 +113,10 @@ class Screen(SignalEvent):
                 return child
 
             # Remove first level Viewport and ScrolledWindow to fill the Vbox
-            for widget in [
-                    self.context_screen.screen_container.viewport,
-                    self.context_screen.current_view.widget.get_children()[0],
-                    ]:
-                remove_bin(widget)
+            remove_bin(self.context_screen.screen_container.viewport)
+            if self.context_screen.current_view:
+                remove_bin(
+                    self.context_screen.current_view.widget.get_children()[0])
 
             self.screen_container.filter_vbox.pack_start(
                 context_widget, expand=False, fill=True, padding=0)
@@ -490,7 +489,8 @@ class Screen(SignalEvent):
         self.group.destroy()
 
     def default_row_activate(self):
-        if (self.current_view.view_type == 'tree'
+        if (self.current_view
+                and self.current_view.view_type == 'tree'
                 and int(self.current_view.attributes.get('keyword_open', 0))):
             return Action.exec_keyword('tree_open', {
                 'model': self.model_name,
@@ -611,7 +611,7 @@ class Screen(SignalEvent):
 
     def new(self, default=True, rec_name=None):
         previous_view = self.current_view
-        if self.current_view.view_type == 'calendar':
+        if self.current_view and self.current_view.view_type == 'calendar':
             selected_date = self.current_view.get_selected_date()
         if self.current_view and not self.current_view.editable:
             self.switch_view('form', display=False)
@@ -664,16 +664,19 @@ class Screen(SignalEvent):
 
     def save_current(self):
         if not self.current_record:
-            if self.current_view.view_type == 'tree' and len(self.group):
+            if (self.current_view
+                    and self.current_view.view_type == 'tree'
+                    and len(self.group)):
                 self.current_record = self.group[0]
             else:
                 return True
-        self.current_view.set_value()
         saved = False
         record_id = None
-        fields = self.current_view.get_fields()
+        if self.current_view:
+            self.current_view.set_value()
+            fields = self.current_view.get_fields()
         path = self.current_record.get_path(self.group)
-        if self.current_view.view_type == 'tree':
+        if self.current_view and self.current_view.view_type == 'tree':
             # False value must be not saved
             saved = all((
                     x is not False and x >= 0
@@ -683,7 +686,7 @@ class Screen(SignalEvent):
             record_id = self.current_record.save(force_reload=True)
             # False value must be not saved
             saved = record_id is not False and record_id >= 0
-        else:
+        elif self.current_view:
             self.set_cursor()
             self.current_view.display()
             return False
@@ -711,17 +714,19 @@ class Screen(SignalEvent):
     def get(self):
         if not self.current_record:
             return None
-        self.current_view.set_value()
+        if self.current_view:
+            self.current_view.set_value()
         return self.current_record.get()
 
     def get_on_change_value(self):
         if not self.current_record:
             return None
-        self.current_view.set_value()
+        if self.current_view:
+            self.current_view.set_value()
         return self.current_record.get_on_change_value()
 
     def modified(self):
-        if self.current_view.view_type != 'tree':
+        if self.current_view and self.current_view.view_type != 'tree':
             if self.current_record:
                 if self.current_record.modified or self.current_record.id < 0:
                     return True
@@ -729,7 +734,7 @@ class Screen(SignalEvent):
             for record in self.group:
                 if record.modified or record.id < 0:
                     return True
-        if self.current_view.modified:
+        if self.current_view and self.current_view.modified:
             return True
         return False
 
@@ -807,6 +812,8 @@ class Screen(SignalEvent):
 
     def set_tree_state(self):
         view = self.current_view
+        if not view:
+            return
         if view.view_type not in ('tree', 'form'):
             return
         if id(view) in self.tree_states_done:
@@ -909,8 +916,10 @@ class Screen(SignalEvent):
 
     def load(self, ids, set_cursor=True, modified=False, position=-1):
         self.group.load(ids, modified=modified, position=position)
-        self.current_view.reset()
-        if ids and self.current_view.view_type != 'calendar':
+        if self.current_view:
+            self.current_view.reset()
+        if (ids and self.current_view
+                and self.current_view.view_type != 'calendar'):
             self.display(ids[0])
         else:
             self.current_record = None
@@ -929,7 +938,7 @@ class Screen(SignalEvent):
                 self.current_record = self.group[0]
             else:
                 self.current_record = None
-        if self.views:
+        if self.views and self.current_view:
             self.search_active(self.current_view.view_type
                 in ('tree', 'graph', 'calendar'))
             for view in self.views:
@@ -974,7 +983,8 @@ class Screen(SignalEvent):
                 model = view.treeview.get_model()
                 iter_ = model.get_iter(end)
                 self.current_record = model.get_value(iter_, 0)
-        elif (view.view_type == 'form'
+        elif (view
+                and view.view_type == 'form'
                 and self.current_record
                 and self.current_record.group):
             group = self.current_record.group
@@ -1002,12 +1012,14 @@ class Screen(SignalEvent):
                 record = next
                 break
             self.current_record = record
-        elif (view.view_type == 'list-form' and len(self.group)
+        elif (view
+                and view.view_type == 'list-form'
+                and len(self.group)
                 and self.current_record in self.group):
             idx = self.group.index(self.current_record)
             if 0 <= idx < len(self.group) - 1:
                 self.current_record = self.group[idx + 1]
-        elif view.view_type == 'calendar':
+        elif view and view.view_type == 'calendar':
             record = self.current_record
             goocalendar = view.widgets.get('goocalendar')
             if goocalendar:
@@ -1039,9 +1051,10 @@ class Screen(SignalEvent):
 
     def display_prev(self):
         view = self.current_view
-        view.set_value()
+        if view:
+            view.set_value()
         self.set_cursor(reset_view=False)
-        if view.view_type == 'tree' and len(self.group):
+        if view and view.view_type == 'tree' and len(self.group):
             range_ = view.treeview.get_visible_range()
             if range_:
                 start, end = range_
@@ -1052,7 +1065,8 @@ class Screen(SignalEvent):
                 model = view.treeview.get_model()
                 iter_ = model.get_iter(start)
                 self.current_record = model.get_value(iter_, 0)
-        elif (view.view_type == 'form'
+        elif (view
+                and view.view_type == 'form'
                 and self.current_record
                 and self.current_record.group):
             group = self.current_record.group
@@ -1070,7 +1084,7 @@ class Screen(SignalEvent):
                 if parent and record.model_name == parent.model_name:
                     record = parent
             self.current_record = record
-        elif view.view_type == 'calendar':
+        elif view and view.view_type == 'calendar':
             record = self.current_record
             goocalendar = view.widgets.get('goocalendar')
             if goocalendar:
@@ -1095,7 +1109,9 @@ class Screen(SignalEvent):
                             if prev_id >= 0:
                                 self.current_record = events[prev_id].record
                             break
-        elif (view.view_type == 'list-form' and len(self.group)
+        elif (view
+                and view.view_type == 'list-form'
+                and len(self.group)
                 and self.current_record in self.group):
             idx = self.group.index(self.current_record)
             if 0 < idx <= len(self.group) - 1:
@@ -1103,7 +1119,8 @@ class Screen(SignalEvent):
         else:
             self.current_record = self.group[-1] if len(self.group) else None
         self.set_cursor(reset_view=False)
-        view.display()
+        if view:
+            view.display()
 
     def invalid_message(self, record=None):
         if record is None:
@@ -1174,7 +1191,7 @@ class Screen(SignalEvent):
         if not self.selected_records:
             return []
 
-        buttons = self.current_view.get_buttons()
+        buttons = self.current_view.get_buttons() if self.current_view else []
 
         for record in self.selected_records:
             buttons = [b for b in buttons if is_active(record, b)]
@@ -1184,8 +1201,9 @@ class Screen(SignalEvent):
 
     def button(self, button):
         'Execute button on the selected records'
-        self.current_view.set_value()
-        fields = self.current_view.get_fields()
+        if self.current_view:
+            self.current_view.set_value()
+            fields = self.current_view.get_fields()
         for record in self.selected_records:
             domain = record.expr_eval(
                 button.get('states', {})).get('pre_validate', [])
@@ -1199,7 +1217,8 @@ class Screen(SignalEvent):
         if button.get('confirm', False) and not sur(button['confirm']):
             return
         if button.get('type', 'class') == 'class':
-            if not self.current_record.save(force_reload=False):
+            record_id = self.current_record.save(force_reload=False)
+            if record_id is False or record_id < 0:
                 return
         if button.get('type', 'class') == 'class':
             self._button_class(button)
@@ -1266,7 +1285,9 @@ class Screen(SignalEvent):
         elif action.startswith('switch'):
             self.switch_view(*action.split(None, 2)[1:])
         elif action == 'reload':
-            if (self.current_view.view_type in ['tree', 'graph', 'calendar']
+            if (self.current_view
+                    and self.current_view.view_type in [
+                        'tree', 'graph', 'calendar']
                     and not self.parent):
                 self.search_filter()
         elif action == 'reload menu':
@@ -1296,7 +1317,7 @@ class Screen(SignalEvent):
                         cls=JSONEncoder, separators=(',', ':'))))
         path = [CONFIG['login.db'], 'model', self.model_name]
         view_ids = [v.view_id for v in self.views] + self.view_ids
-        if self.current_view.view_type != 'form':
+        if self.current_view and self.current_view.view_type != 'form':
             if self.search_value:
                 search_value = self.search_value
             else:
@@ -1308,8 +1329,9 @@ class Screen(SignalEvent):
                             separators=(',', ':'))))
         elif self.current_record and self.current_record.id > -1:
             path.append(str(self.current_record.id))
-            i = view_ids.index(self.current_view.view_id)
-            view_ids = view_ids[i:] + view_ids[:i]
+            if self.current_view:
+                i = view_ids.index(self.current_view.view_id)
+                view_ids = view_ids[i:] + view_ids[:i]
         if view_ids:
             query_string.append(('views', json.dumps(
                         view_ids, separators=(',', ':'))))
