@@ -28,7 +28,8 @@ from tryton.common import data2pixbuf
 from tryton.common.completion import get_completion, update_completion
 from tryton.common.selection import (
     SelectionMixin, PopdownMixin, selection_shortcuts)
-from tryton.common.datetime_ import CellRendererDate, CellRendererTime
+from tryton.common.datetime_ import (
+    CellRendererDate, CellRendererTime, date_parse)
 from tryton.common.domain_parser import quote
 from tryton.config import CONFIG
 
@@ -358,6 +359,14 @@ class GenericText(Cell):
         editable.connect('remove-widget', remove)
         return False
 
+    def get_editable(self, renderer):
+        if self.renderer == renderer:
+            return self.editable
+        for cell in self.prefixes + self.suffixes:
+            editable = cell.get_editable(renderer)
+            if editable:
+                return editable
+
 
 class Char(GenericText):
 
@@ -474,6 +483,17 @@ class Date(GenericText):
         else:
             return ''
 
+    def value_from_text(self, record, text, callback=None):
+        if isinstance(text, str):
+            field = record[self.attrs['name']]
+            try:
+                # Use a datetime instance and rely on field to convert to the
+                # proper type
+                text = date_parse(text, self.get_format(record, field))
+            except (ValueError, OverflowError):
+                text = None
+        return super().value_from_text(record, text, callback=callback)
+
 
 class Time(Date):
 
